# use command: pip install -e .
# to install and test it locally before you publish it
cert = {
  "type": "service_account",
  "project_id": "cariindongs",
  "private_key_id": "d32b81081412f0e50ee1a2d0f7b0d3327f65eac9",
  "private_key": "-----BEGIN PRIVATE KEY-----\nMIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQCgiB6Uyfmgs7j3\nwSNNlhbcCiHPNjpkCncRW6FnaWvoAbAcDbCjsielgaBRCax4Me452AtXuOAu5uoN\n+5Yy1bSlaHiTYPfg4SD9Y64N90rZt2BCAx5c0M2O0Hm/frXfIdw61Hsbumv2RuFn\nhQW+JmPvNdrLhclBceLd3yfmv6K0liXFcePeBerSmg9xK+hkietJmagjAqClUHh/\nuFDV+HOEZXj7dGGzAm0CUubX8AgF2fN03n/etw4uui/x3AL2jUJ+bYlPZwRfUluu\nmc4L1PQS874UJAMuQp8u3VaIBo9ggn9HC4xIBL2D3y5RfOtMHYXqlk+YqbNVRS+U\nj6N7GyxjAgMBAAECggEAATtqOKwgLVqTxdsGoVbQkBnHzqZU5mWqKkjwwTFu8ZXp\nux1jyK3aXgvTpiuT1kxTzr/YvnCdz95X14mhynwXadmWa1MoM+KmdStpr5PBUFB2\n/aq2dfHoUftJo+2eCbthzFXLKBhTMc2zdy7vL1luFOzt4/f/5m+wVRGcZcn8vrQR\nMsxTgS9TN/K4cYb33O2rl9TcKKwyhSprJq6tOorg1FaDGcPArz2vkdy2oqiWVKQo\nBh7XdvkWH/Vy9ivA03h7qnmE2FuTx6KlkRWzY661VYoDDIYMYlPIfQCKv+X/ggQ/\nmh6MaYUuzf7MpZDcwRMsLjPpZBzE6wE6oO5pw2ObiQKBgQDTgFV7nHUsKV7g7wsT\nuMeelRZYiEjzB9IU6Eikc4bFBKMJKwCYViA+LxGZZoelAV79IwtNw4wzrv78flRU\nOWVX5lCGhQDbiFDG1yGZJCPXvILFrdBExeFM9uhHMXKLj/DiEtk3/cv5vC/NAEyc\nSBrP8IVuJalI7btXA64rzTPmFwKBgQDCToORusgDvRxyEnWgTVUepQOSAVnl7Glc\najpHgGrgRAn5mQ1CfstgbE3F37xeUhnsgj5JGmDAhQmehf9JWDorQHsA0U8v216d\noWKW78kF0W4gVXt9Ekh6BpL1qq7IQrJheFGdCMYWI382YTdFYK0T8Nul4+f4g/by\ncMu8/yVnlQKBgAcyWLZKDpqgFcBloeTb5r74p7f/eyv52iYn+UDPRYiyrbGEKxMD\n6zjydRDZMkhlEYxfguT0gHLJw5dn3Qq4oUAqcBcDs5HEw6rgax5A4o9WtMRxM6MD\ncLUjuaeigRlKnpGyvn1vP1+SDbZWCkVPFsp4jrG+ylHW9Qby8xw+cUOlAoGBAI7P\ndhQd2/Qjgky1FI8FR5KGZeFh7Nj4sVejG8KBuAus9kflHcHJv2DXOTI+Bwyr+zHB\naFYCdSoKnc9NXRxjJB21/rHTJQhfi2L/wp59DpqgGvjY2zJJxcsqGclF8cBuhPzu\nmc15LV4IKO+m9CChtZP6avW6VDxrgY0fKh92x98hAoGAOt8XbNsmOnWszWT6/hRn\n17RhUhz4N6IC40h1Hun2ZniBeHWZnZkDB5xCzJB/U1kx/viOHxKHMaS1h03r51CW\nLqTGtcTa8OYBpDqZ7347e6k6D9VcGDqHJUmig42brnpgqiuGBCxF74zYWrtJwCp8\n5Ws9u3g9Q69Kias9XVf8OY4=\n-----END PRIVATE KEY-----\n",
  "client_email": "predictnowai@cariindongs.iam.gserviceaccount.com",
  "client_id": "113067777628006977676",
  "auth_uri": "https://accounts.google.com/o/oauth2/auth",
  "token_uri": "https://oauth2.googleapis.com/token",
  "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
  "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/predictnowai%40cariindongs.iam.gserviceaccount.com"
}